@@ -11,8 +11,8 @@ def test_basics(qtbot):
     Basic test that works more like a sanity check to ensure we are setting up a QApplication
     properly and are able to display a simple event_recorder.
     """
-    assert qt_api.QApplication.instance() is not None
-    widget = qt_api.QWidget()
+    assert qt_api.QtWidgets.QApplication.instance() is not None
+    widget = qt_api.QtWidgets.QWidget()
     qtbot.addWidget(widget)
     widget.setWindowTitle("W1")
     widget.show()
@@ -21,27 +21,52 @@ def test_basics(qtbot):
     assert widget.windowTitle() == "W1"
 
 
+def test_qapp_default_name(qapp):
+    assert qapp.applicationName() == "pytest-qt-qapp"
+
+
+def test_qapp_name(testdir):
+    testdir.makepyfile(
+        """
+    def test_name(qapp):
+        assert qapp.applicationName() == "frobnicator"
+    """
+    )
+    testdir.makeini(
+        """
+        [pytest]
+        qt_qapp_name = frobnicator
+        """
+    )
+    res = testdir.runpytest_subprocess()
+    res.stdout.fnmatch_lines("*1 passed*")
+
+
 def test_key_events(qtbot, event_recorder):
     """
     Basic key events test.
     """
 
     def extract(key_event):
-        return (key_event.type(), key_event.key(), key_event.text())
+        return (
+            key_event.type(),
+            qt_api.QtCore.Qt.Key(key_event.key()),
+            key_event.text(),
+        )
 
     event_recorder.registerEvent(qt_api.QtGui.QKeyEvent, extract)
 
     qtbot.keyPress(event_recorder, "a")
     assert event_recorder.event_data == (
-        qt_api.QEvent.KeyPress,
-        int(qt_api.Qt.Key_A),
+        qt_api.QtCore.QEvent.Type.KeyPress,
+        qt_api.QtCore.Qt.Key.Key_A,
         "a",
     )
 
     qtbot.keyRelease(event_recorder, "a")
     assert event_recorder.event_data == (
-        qt_api.QEvent.KeyRelease,
-        int(qt_api.Qt.Key_A),
+        qt_api.QtCore.QEvent.Type.KeyRelease,
+        qt_api.QtCore.Qt.Key.Key_A,
         "a",
     )
 
@@ -56,30 +81,37 @@ def test_mouse_events(qtbot, event_recorder):
 
     event_recorder.registerEvent(qt_api.QtGui.QMouseEvent, extract)
 
-    qtbot.mousePress(event_recorder, qt_api.Qt.LeftButton)
+    qtbot.mousePress(event_recorder, qt_api.QtCore.Qt.MouseButton.LeftButton)
     assert event_recorder.event_data == (
-        qt_api.QEvent.MouseButtonPress,
-        qt_api.Qt.LeftButton,
-        qt_api.Qt.NoModifier,
+        qt_api.QtCore.QEvent.Type.MouseButtonPress,
+        qt_api.QtCore.Qt.MouseButton.LeftButton,
+        qt_api.QtCore.Qt.KeyboardModifier.NoModifier,
     )
 
-    qtbot.mousePress(event_recorder, qt_api.Qt.RightButton, qt_api.Qt.AltModifier)
+    qtbot.mousePress(
+        event_recorder,
+        qt_api.QtCore.Qt.MouseButton.RightButton,
+        qt_api.QtCore.Qt.KeyboardModifier.AltModifier,
+    )
     assert event_recorder.event_data == (
-        qt_api.QEvent.MouseButtonPress,
-        qt_api.Qt.RightButton,
-        qt_api.Qt.AltModifier,
+        qt_api.QtCore.QEvent.Type.MouseButtonPress,
+        qt_api.QtCore.Qt.MouseButton.RightButton,
+        qt_api.QtCore.Qt.KeyboardModifier.AltModifier,
     )
 
 
-def test_stop_for_interaction(qtbot, timer):
+def test_stop(qtbot, timer):
     """
-    Test qtbot.stopForInteraction()
+    Test qtbot.stop()
     """
-    widget = qt_api.QWidget()
+    widget = qt_api.QtWidgets.QWidget()
     qtbot.addWidget(widget)
-    qtbot.waitForWindowShown(widget)
+
+    with qtbot.waitExposed(widget):
+        widget.show()
+
     timer.single_shot_callback(widget.close, 0)
-    qtbot.stopForInteraction()
+    qtbot.stop()
 
 
 @pytest.mark.parametrize("show", [True, False])
@@ -90,21 +122,29 @@ def test_wait_window(show, method_name, qtbot):
     is properly displayed, otherwise should raise a TimeoutError.
     """
     method = getattr(qtbot, method_name)
-    if qt_api.pytest_qt_api != "pyqt5":
-        with pytest.raises(RuntimeError) as exc_info:
-            with method(None, None):
-                pass
-        assert str(exc_info.value) == "Available in PyQt5 only"
+    widget = qt_api.QtWidgets.QWidget()
+    qtbot.add_widget(widget)
+    if show:
+        with method(widget, timeout=1000):
+            widget.show()
     else:
-        widget = qt_api.QWidget()
-        qtbot.add_widget(widget)
-        if show:
-            with method(widget, timeout=1000):
-                widget.show()
-        else:
-            with pytest.raises(qtbot.TimeoutError):
-                with method(widget, timeout=100):
-                    pass
+        with pytest.raises(qtbot.TimeoutError):
+            with method(widget, timeout=100):
+                pass
+
+
+@pytest.mark.parametrize("show", [True, False])
+def test_wait_for_window_shown(qtbot, show):
+    widget = qt_api.QtWidgets.QWidget()
+    qtbot.add_widget(widget)
+
+    if show:
+        widget.show()
+
+    with pytest.deprecated_call(match="waitForWindowShown is deprecated"):
+        shown = qtbot.waitForWindowShown(widget)
+
+    assert shown == show
 
 
 @pytest.mark.parametrize("method_name", ["waitExposed", "waitActive"])
@@ -113,24 +153,20 @@ def test_wait_window_propagates_other_exception(method_name, qtbot):
     Exceptions raised inside the with-statement of wait-widget methods should
     propagate properly.
     """
-    if qt_api.pytest_qt_api != "pyqt5":
-        pytest.skip("Available in PyQt5 only")
-
     method = getattr(qtbot, method_name)
-    widget = qt_api.QWidget()
+    widget = qt_api.QtWidgets.QWidget()
     qtbot.add_widget(widget)
-    with pytest.raises(ValueError) as exc_info:
+    with pytest.raises(ValueError, match="some other error"):
         with method(widget, timeout=100):
             widget.show()
             raise ValueError("some other error")
-    assert str(exc_info.value) == "some other error"
 
 
 def test_widget_kept_as_weakref(qtbot):
     """
     Test if the widget is kept as a weak reference in QtBot
     """
-    widget = qt_api.QWidget()
+    widget = qt_api.QtWidgets.QWidget()
     qtbot.add_widget(widget)
     widget = weakref.ref(widget)
     assert widget() is None
@@ -161,10 +197,10 @@ def test_event_processing_before_and_after_teardown(testdir):
                     self.events = []
 
                 def pop_later(self):
-                    qapp.postEvent(self, qt_api.QEvent(qt_api.QEvent.User))
+                    qapp.postEvent(self, qt_api.QtCore.QEvent(qt_api.QtCore.QEvent.Type.User))
 
                 def event(self, ev):
-                    if ev.type() == qt_api.QEvent.User:
+                    if ev.type() == qt_api.QtCore.QEvent.Type.User:
                         self.events.pop(-1)
                     return qt_api.QtCore.QObject.event(self, ev)
 
@@ -208,38 +244,18 @@ def test_header(testdir):
     )
 
 
-def test_public_api_backward_compatibility():
-    """
-    Test backward compatibility for version 1.6.0: since then symbols that were available from
-    pytestqt.plugin have been moved to other modules to enhance navigation and maintainability,
-    this test ensures the same symbols are still available from the same imports. (#90)
-    """
-    import pytestqt.plugin
-
-    assert pytestqt.plugin.QtBot
-    assert pytestqt.plugin.SignalBlocker
-    assert pytestqt.plugin.MultiSignalBlocker
-    assert pytestqt.plugin.SignalTimeoutError
-    assert pytestqt.plugin.format_captured_exceptions
-    assert pytestqt.plugin.capture_exceptions
-    assert pytestqt.plugin.QtLoggingPlugin
-    assert pytestqt.plugin.Record
-
-
 def test_qvariant(tmpdir):
-    """Test that make_variant and extract_from_variant work in the same way
-    across all supported Qt bindings.
-    """
+    """Test that QVariant works in the same way across all supported Qt bindings."""
     settings = qt_api.QtCore.QSettings(
-        str(tmpdir / "foo.ini"), qt_api.QtCore.QSettings.IniFormat
+        str(tmpdir / "foo.ini"), qt_api.QtCore.QSettings.Format.IniFormat
     )
-    settings.setValue("int", qt_api.make_variant(42))
-    settings.setValue("str", qt_api.make_variant("Hello"))
-    settings.setValue("empty", qt_api.make_variant())
+    settings.setValue("int", 42)
+    settings.setValue("str", "Hello")
+    settings.setValue("empty", None)
 
-    assert qt_api.extract_from_variant(settings.value("int")) == 42
-    assert qt_api.extract_from_variant(settings.value("str")) == "Hello"
-    assert qt_api.extract_from_variant(settings.value("empty")) is None
+    assert settings.value("int") == 42
+    assert settings.value("str") == "Hello"
+    assert settings.value("empty") is None
 
 
 def test_widgets_closed_before_fixtures(testdir):
@@ -252,7 +268,7 @@ def test_widgets_closed_before_fixtures(testdir):
         import pytest
         from pytestqt.qt_compat import qt_api
 
-        class Widget(qt_api.QWidget):
+        class Widget(qt_api.QtWidgets.QWidget):
 
             closed = False
 
@@ -284,7 +300,7 @@ def test_qtbot_wait(qtbot, stop_watch):
 
 @pytest.fixture
 def event_recorder(qtbot):
-    class EventRecorder(qt_api.QWidget):
+    class EventRecorder(qt_api.QtWidgets.QWidget):
 
         """
         Widget that records some kind of events sent to it.
@@ -295,7 +311,7 @@ def event_recorder(qtbot):
         """
 
         def __init__(self):
-            qt_api.QWidget.__init__(self)
+            qt_api.QtWidgets.QWidget.__init__(self)
             self._event_types = {}
             self.event_data = None
 
@@ -339,7 +355,7 @@ def test_parse_ini_boolean_invalid():
         pytestqt.qtbot._parse_ini_boolean("foo")
 
 
-@pytest.mark.parametrize("option_api", ["pyqt4", "pyqt5", "pyside", "pyside2"])
+@pytest.mark.parametrize("option_api", ["pyqt5", "pyqt6", "pyside2", "pyside6"])
 def test_qt_api_ini_config(testdir, monkeypatch, option_api):
     """
     Test qt_api ini option handling.
@@ -367,7 +383,7 @@ def test_qt_api_ini_config(testdir, monkeypatch, option_api):
     )
 
     result = testdir.runpytest_subprocess()
-    if qt_api.pytest_qt_api.replace("v2", "") == option_api:  # handle pyqt4v2
+    if qt_api.pytest_qt_api == option_api:
         result.stdout.fnmatch_lines(["* 1 passed in *"])
     else:
         try:
@@ -380,10 +396,9 @@ def test_qt_api_ini_config(testdir, monkeypatch, option_api):
             result.stderr.fnmatch_lines(["*ModuleNotFoundError:*"])
 
 
-@pytest.mark.parametrize("envvar", ["pyqt4", "pyqt5", "pyside", "pyside2"])
+@pytest.mark.parametrize("envvar", ["pyqt5", "pyqt6", "pyside2", "pyside6"])
 def test_qt_api_ini_config_with_envvar(testdir, monkeypatch, envvar):
-    """ensure environment variable wins over config value if both are present
-    """
+    """ensure environment variable wins over config value if both are present"""
     testdir.makeini(
         """
         [pytest]
@@ -405,7 +420,7 @@ def test_qt_api_ini_config_with_envvar(testdir, monkeypatch, envvar):
     )
 
     result = testdir.runpytest_subprocess()
-    if qt_api.pytest_qt_api.replace("v2", "") == envvar:
+    if qt_api.pytest_qt_api == envvar:
         result.stdout.fnmatch_lines(["* 1 passed in *"])
     else:
         try:
@@ -432,13 +447,11 @@ def test_invalid_qt_api_envvar(testdir, monkeypatch):
     )
     monkeypatch.setenv("PYTEST_QT_API", "piecute")
     result = testdir.runpytest_subprocess()
-    result.stderr.fnmatch_lines(["* Invalid value for $PYTEST_QT_API: piecute"])
+    result.stderr.fnmatch_lines(
+        ["* Invalid value for $PYTEST_QT_API: piecute, expected one of *"]
+    )
 
 
-@pytest.mark.skipif(
-    qt_api.pytest_qt_api in ["pyqt4", "pyqt4v2", "pyside"],
-    reason="QApplication.arguments() doesn't return custom arguments with Qt4 and Windows",
-)
 def test_qapp_args(testdir):
     """
     Test customizing of QApplication arguments.
@@ -464,20 +477,20 @@ def test_qapp_args(testdir):
 
 def test_importerror(monkeypatch):
     def _fake_import(name, *args):
-        raise ImportError("Failed to import {}".format(name))
+        raise ModuleNotFoundError(f"Failed to import {name}")
 
     monkeypatch.delenv("PYTEST_QT_API", raising=False)
     monkeypatch.setattr(qt_compat, "_import", _fake_import)
 
     expected = (
-        "pytest-qt requires either PySide, PySide2, PyQt4 or PyQt5 to be installed\n"
-        "  PyQt4.QtCore: Failed to import PyQt4.QtCore\n"
+        "pytest-qt requires either PySide2, PySide6, PyQt5 or PyQt6 installed.\n"
         "  PyQt5.QtCore: Failed to import PyQt5.QtCore\n"
-        "  PySide.QtCore: Failed to import PySide.QtCore\n"
-        "  PySide2.QtCore: Failed to import PySide2.QtCore"
+        "  PyQt6.QtCore: Failed to import PyQt6.QtCore\n"
+        "  PySide2.QtCore: Failed to import PySide2.QtCore\n"
+        "  PySide6.QtCore: Failed to import PySide6.QtCore"
     )
 
-    with pytest.raises(RuntimeError, match=expected):
+    with pytest.raises(pytest.UsageError, match=expected):
         qt_api.set_qt_api(api=None)
 
 
@@ -499,7 +512,7 @@ def test_before_close_func(testdir):
 
         @pytest.fixture
         def widget(qtbot):
-            w = qt_api.QWidget()
+            w = qt_api.QtWidgets.QWidget()
             w.some_id = 'my id'
             qtbot.add_widget(w, before_close_func=widget_closed)
             return w
@@ -511,3 +524,12 @@ def test_before_close_func(testdir):
     result = testdir.runpytest_inprocess()
     result.stdout.fnmatch_lines(["*= 1 passed in *"])
     assert sys.pytest_qt_widget_closed
+
+
+def test_addwidget_typeerror(testdir, qtbot):
+    """
+    Make sure addWidget catches type errors early.
+    """
+    obj = qt_api.QtCore.QObject()
+    with pytest.raises(TypeError):
+        qtbot.addWidget(obj)
