@@ -7,7 +7,7 @@ pytestmark = pytest.mark.usefixtures("qtbot")
 
 
 class BasicModel(qt_api.QtCore.QAbstractItemModel):
-    def data(self, index, role=qt_api.QtCore.Qt.DisplayRole):
+    def data(self, index, role=qt_api.QtCore.Qt.ItemDataRole.DisplayRole):
         return None
 
     def rowCount(self, parent=qt_api.QtCore.QModelIndex()):
@@ -25,10 +25,10 @@ class BasicModel(qt_api.QtCore.QAbstractItemModel):
 
 def test_standard_item_model(qtmodeltester):
     """
-    Basic test which uses qtmodeltester with a qt_api.QStandardItemModel.
+    Basic test which uses qtmodeltester with a qt_api.QtGui.QStandardItemModel.
     """
-    model = qt_api.QStandardItemModel()
-    items = [qt_api.QStandardItem(str(i)) for i in range(6)]
+    model = qt_api.QtGui.QStandardItemModel()
+    items = [qt_api.QtGui.QStandardItem(str(i)) for i in range(6)]
     model.setItem(0, 0, items[0])
     model.setItem(0, 1, items[1])
     model.setItem(1, 0, items[2])
@@ -41,15 +41,15 @@ def test_standard_item_model(qtmodeltester):
 
 
 def test_string_list_model(qtmodeltester):
-    model = qt_api.QStringListModel()
+    model = qt_api.QtCore.QStringListModel()
     model.setStringList(["hello", "world"])
     qtmodeltester.check(model, force_py=True)
 
 
 def test_sort_filter_proxy_model(qtmodeltester):
-    model = qt_api.QStringListModel()
+    model = qt_api.QtCore.QStringListModel()
     model.setStringList(["hello", "world"])
-    proxy = qt_api.QSortFilterProxyModel()
+    proxy = qt_api.QtCore.QSortFilterProxyModel()
     proxy.setSourceModel(model)
     qtmodeltester.check(proxy, force_py=True)
 
@@ -57,15 +57,15 @@ def test_sort_filter_proxy_model(qtmodeltester):
 @pytest.mark.parametrize(
     "broken_role",
     [
-        qt_api.QtCore.Qt.ToolTipRole,
-        qt_api.QtCore.Qt.StatusTipRole,
-        qt_api.QtCore.Qt.WhatsThisRole,
-        qt_api.QtCore.Qt.SizeHintRole,
-        qt_api.QtCore.Qt.FontRole,
-        qt_api.QtCore.Qt.BackgroundColorRole,
-        qt_api.QtCore.Qt.TextColorRole,
-        qt_api.QtCore.Qt.TextAlignmentRole,
-        qt_api.QtCore.Qt.CheckStateRole,
+        qt_api.QtCore.Qt.ItemDataRole.ToolTipRole,
+        qt_api.QtCore.Qt.ItemDataRole.StatusTipRole,
+        qt_api.QtCore.Qt.ItemDataRole.WhatsThisRole,
+        qt_api.QtCore.Qt.ItemDataRole.SizeHintRole,
+        qt_api.QtCore.Qt.ItemDataRole.FontRole,
+        qt_api.QtCore.Qt.ItemDataRole.BackgroundRole,
+        qt_api.QtCore.Qt.ItemDataRole.ForegroundRole,
+        qt_api.QtCore.Qt.ItemDataRole.TextAlignmentRole,
+        qt_api.QtCore.Qt.ItemDataRole.CheckStateRole,
     ],
 )
 def test_broken_types(check_model, broken_role):
@@ -74,7 +74,7 @@ def test_broken_types(check_model, broken_role):
     values for various display roles.
     """
 
-    class BrokenTypeModel(qt_api.QAbstractListModel):
+    class BrokenTypeModel(qt_api.QtCore.QAbstractListModel):
         def rowCount(self, parent=qt_api.QtCore.QModelIndex()):
             if parent == qt_api.QtCore.QModelIndex():
                 return 1
@@ -82,7 +82,9 @@ def test_broken_types(check_model, broken_role):
                 return 0
 
         def data(
-            self, index=qt_api.QtCore.QModelIndex(), role=qt_api.QtCore.Qt.DisplayRole
+            self,
+            index=qt_api.QtCore.QModelIndex(),
+            role=qt_api.QtCore.Qt.ItemDataRole.DisplayRole,
         ):
             if role == broken_role:
                 return object()  # This will fail the type check for any role
@@ -95,8 +97,8 @@ def test_broken_types(check_model, broken_role):
 @pytest.mark.parametrize(
     "role_value, should_pass",
     [
-        (qt_api.QtCore.Qt.AlignLeft, True),
-        (qt_api.QtCore.Qt.AlignRight, True),
+        (qt_api.QtCore.Qt.AlignmentFlag.AlignLeft, True),
+        (qt_api.QtCore.Qt.AlignmentFlag.AlignRight, True),
         (0xFFFFFF, False),
         ("foo", False),
         (object(), False),
@@ -107,16 +109,18 @@ def test_data_alignment(role_value, should_pass, check_model):
     qtmodeltest should capture this problem and fail when that happens.
     """
 
-    class MyModel(qt_api.QAbstractListModel):
+    class MyModel(qt_api.QtCore.QAbstractListModel):
         def rowCount(self, parent=qt_api.QtCore.QModelIndex()):
             return 1 if parent == qt_api.QtCore.QModelIndex() else 0
 
         def data(
-            self, index=qt_api.QtCore.QModelIndex(), role=qt_api.QtCore.Qt.DisplayRole
+            self,
+            index=qt_api.QtCore.QModelIndex(),
+            role=qt_api.QtCore.Qt.ItemDataRole.DisplayRole,
         ):
-            if role == qt_api.QtCore.Qt.TextAlignmentRole:
+            if role == qt_api.QtCore.Qt.ItemDataRole.TextAlignmentRole:
                 return role_value
-            elif role == qt_api.QtCore.Qt.DisplayRole:
+            elif role == qt_api.QtCore.Qt.ItemDataRole.DisplayRole:
                 if index == self.index(0, 0):
                     return "Hello"
             return None
@@ -125,22 +129,29 @@ def test_data_alignment(role_value, should_pass, check_model):
 
 
 def test_header_handling(check_model):
-    class MyModel(qt_api.QAbstractListModel):
+    class MyModel(qt_api.QtCore.QAbstractListModel):
         def rowCount(self, parent=qt_api.QtCore.QModelIndex()):
             return 1 if parent == qt_api.QtCore.QModelIndex() else 0
 
         def set_header_text(self, header):
             self._header_text = header
-            self.headerDataChanged.emit(qt_api.QtCore.Qt.Vertical, 0, 0)
-            self.headerDataChanged.emit(qt_api.QtCore.Qt.Horizontal, 0, 0)
+            self.headerDataChanged.emit(qt_api.QtCore.Qt.Orientation.Vertical, 0, 0)
+            self.headerDataChanged.emit(qt_api.QtCore.Qt.Orientation.Horizontal, 0, 0)
 
-        def headerData(self, section, orientation, role=qt_api.QtCore.Qt.DisplayRole):
+        def headerData(
+            self, section, orientation, role=qt_api.QtCore.Qt.ItemDataRole.DisplayRole
+        ):
             return self._header_text
 
         def data(
-            self, index=qt_api.QtCore.QModelIndex(), role=qt_api.QtCore.Qt.DisplayRole
+            self,
+            index=qt_api.QtCore.QModelIndex(),
+            role=qt_api.QtCore.Qt.ItemDataRole.DisplayRole,
         ):
-            if role == qt_api.QtCore.Qt.DisplayRole and index == self.index(0, 0):
+            if (
+                role == qt_api.QtCore.Qt.ItemDataRole.DisplayRole
+                and index == self.index(0, 0)
+            ):
                 return "Contents"
             return None
 
@@ -182,34 +193,35 @@ def test_invalid_column_count(qtmodeltester):
 
 
 def test_changing_model_insert(qtmodeltester):
-    model = qt_api.QStandardItemModel()
-    item = qt_api.QStandardItem("foo")
+    model = qt_api.QtGui.QStandardItemModel()
+    item = qt_api.QtGui.QStandardItem("foo")
     qtmodeltester.check(model, force_py=True)
     model.insertRow(0, item)
 
 
 def test_changing_model_remove(qtmodeltester):
-    model = qt_api.QStandardItemModel()
-    item = qt_api.QStandardItem("foo")
+    model = qt_api.QtGui.QStandardItemModel()
+    item = qt_api.QtGui.QStandardItem("foo")
     model.setItem(0, 0, item)
     qtmodeltester.check(model, force_py=True)
     model.removeRow(0)
 
 
 def test_changing_model_data(qtmodeltester):
-    model = qt_api.QStandardItemModel()
-    item = qt_api.QStandardItem("foo")
+    model = qt_api.QtGui.QStandardItemModel()
+    item = qt_api.QtGui.QStandardItem("foo")
     model.setItem(0, 0, item)
     qtmodeltester.check(model, force_py=True)
     model.setData(model.index(0, 0), "hello world")
 
 
 @pytest.mark.parametrize(
-    "orientation", [qt_api.QtCore.Qt.Horizontal, qt_api.QtCore.Qt.Vertical]
+    "orientation",
+    [qt_api.QtCore.Qt.Orientation.Horizontal, qt_api.QtCore.Qt.Orientation.Vertical],
 )
 def test_changing_model_header_data(qtmodeltester, orientation):
-    model = qt_api.QStandardItemModel()
-    item = qt_api.QStandardItem("foo")
+    model = qt_api.QtGui.QStandardItemModel()
+    item = qt_api.QtGui.QStandardItem("foo")
     model.setItem(0, 0, item)
     qtmodeltester.check(model, force_py=True)
     model.setHeaderData(0, orientation, "blah")
@@ -217,8 +229,8 @@ def test_changing_model_header_data(qtmodeltester, orientation):
 
 def test_changing_model_sort(qtmodeltester):
     """Sorting emits layoutChanged"""
-    model = qt_api.QStandardItemModel()
-    item = qt_api.QStandardItem("foo")
+    model = qt_api.QtGui.QStandardItemModel()
+    item = qt_api.QtGui.QStandardItem("foo")
     model.setItem(0, 0, item)
     qtmodeltester.check(model, force_py=True)
     model.sort(0)
@@ -238,7 +250,7 @@ def test_overridden_methods(qtmodeltester):
 
     class Model(BasicModel):
         def __init__(self, parent=None):
-            super(Model, self).__init__(parent)
+            super().__init__(parent)
             self.row_count_did_run = False
 
         def rowCount(self, parent=None):
@@ -252,7 +264,7 @@ def test_overridden_methods(qtmodeltester):
 
 
 def test_fetch_more(qtmodeltester):
-    class Model(qt_api.QStandardItemModel):
+    class Model(qt_api.QtGui.QStandardItemModel):
         def canFetchMore(self, parent):
             return True
 
@@ -261,13 +273,13 @@ def test_fetch_more(qtmodeltester):
             self.setData(self.index(0, 0), "bar")
 
     model = Model()
-    item = qt_api.QStandardItem("foo")
+    item = qt_api.QtGui.QStandardItem("foo")
     model.setItem(0, 0, item)
     qtmodeltester.check(model, force_py=True)
 
 
 def test_invalid_parent(qtmodeltester):
-    class Model(qt_api.QStandardItemModel):
+    class Model(qt_api.QtGui.QStandardItemModel):
         def parent(self, index):
             if index == self.index(0, 0, parent=self.index(0, 0)):
                 return self.index(0, 0)
@@ -275,9 +287,9 @@ def test_invalid_parent(qtmodeltester):
                 return qt_api.QtCore.QModelIndex()
 
     model = Model()
-    item = qt_api.QStandardItem("foo")
-    item2 = qt_api.QStandardItem("bar")
-    item3 = qt_api.QStandardItem("bar")
+    item = qt_api.QtGui.QStandardItem("foo")
+    item2 = qt_api.QtGui.QStandardItem("bar")
+    item3 = qt_api.QtGui.QStandardItem("bar")
     model.setItem(0, 0, item)
     item.setChild(0, item2)
     item2.setChild(0, item3)
@@ -297,7 +309,7 @@ def test_qt_tester_valid(testdir):
 
 
         def test_ok(qtmodeltester):
-            model = qt_api.QStandardItemModel()
+            model = qt_api.QtGui.QStandardItemModel()
             qtmodeltester.check(model)
         """
     )
@@ -322,7 +334,7 @@ def test_qt_tester_invalid(testdir):
 
 
         class Model(qt_api.QtCore.QAbstractItemModel):
-            def data(self, index, role=qt_api.QtCore.Qt.DisplayRole):
+            def data(self, index, role=qt_api.QtCore.Qt.ItemDataRole.DisplayRole):
                 return None
 
             def rowCount(self, parent=qt_api.QtCore.QModelIndex()):
@@ -349,8 +361,8 @@ def test_qt_tester_invalid(testdir):
             "*__ test_ok __*",
             "test_qt_tester_invalid.py:*: Qt modeltester errors",
             "*-- Captured Qt messages --*",
-            "* QtWarningMsg: FAIL! model->columnCount(QModelIndex()) >= 0 () returned FALSE "
-            "(qabstractitemmodeltester.cpp:*)",
+            "*QtWarningMsg: FAIL! model->columnCount(QModelIndex()) >= 0 () returned FALSE "
+            "(*qabstractitemmodeltester.cpp:*)",
             "*-- Captured stdout call --*",
             "modeltest: Using Qt C++ tester",
             "*== 1 failed in * ==*",
